@@ -1,14 +1,14 @@
-
-from tiddlywebplugins.instancer.util import get_tiddler_locations
-
+"""
+Contents and structure of a manifestopheles instance.
+"""
 store_contents = {}
 store_structure = {}
 store_structure['bags'] = {}
 
 store_contents['static'] = [
-        'file:static/feelies.js.tid',
-        'file:static/feelies.css.tid',
-        ]
+        'static/feelies.js.tid',
+        'static/feelies.css.tid',
+]
 
 store_structure['bags']['static'] = {
         'desc': 'static stuff',
@@ -19,12 +19,11 @@ store_structure['bags']['static'] = {
             'delete': ['R:ADMIN'],
             'manage': ['R:ADMIN'],
             'owner': 'administrator',
-            },
-        }
+        },
+}
 
 
 instance_config = {
         'system_plugins': ['tiddlywebplugins.manifestopheles'],
         'twanager_plugins': ['tiddlywebplugins.manifestopheles'],
-        }
-
+}
